Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(470)

Unified Diff: remoting/webapp/remoting.js

Issue 12566035: Added survey butter-bar to web-app. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Improved string grammar. Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/webapp/manifest.json ('k') | remoting/webapp/survey.js » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/webapp/remoting.js
diff --git a/remoting/webapp/remoting.js b/remoting/webapp/remoting.js
index b84058b662507123e2c827f80902334ec506ad84..931d0f71b88069b14f780a1a01cc825365d78dd0 100644
--- a/remoting/webapp/remoting.js
+++ b/remoting/webapp/remoting.js
@@ -93,7 +93,7 @@ remoting.init = function() {
}
}
// No valid URL parameters, start up normally.
- remoting.initDaemonUi();
+ remoting.initHomeScreenUi();
}
remoting.hostList.load(onLoad);
@@ -122,9 +122,11 @@ remoting.onEmail = function(email) {
document.getElementById('get-started-me2me').disabled = false;
};
-/** initDaemonUi is called if the app is not starting up in session mode, and
- * also if the user cancels pin entry or the connection in session mode. */
-remoting.initDaemonUi = function() {
+/**
+ * initHomeScreenUi is called if the app is not starting up in session mode,
+ * and also if the user cancels pin entry or the connection in session mode.
+ */
+remoting.initHomeScreenUi = function() {
remoting.hostController = new remoting.HostController();
document.getElementById('share-button').disabled =
!remoting.hostController.isPluginSupported();
@@ -137,6 +139,7 @@ remoting.initDaemonUi = function() {
// Display the cached host list, then asynchronously update and re-display it.
remoting.updateLocalHostState();
remoting.hostList.refresh(remoting.updateLocalHostState);
+ remoting.initSurvey();
};
/**
« no previous file with comments | « remoting/webapp/manifest.json ('k') | remoting/webapp/survey.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698